---
layout: page

title: Bylaws

narrow: true
---

# Definitions

1. **Advisor** means an individual appointed to serve as an advisor to the Foundation.
1. **Advisory Committee** means a subset of Advisors established by the Board to provide advice on a specific subject area.
1. **Applicant** means an entity that has applied to become a Caretaker.
1. **Articles** means the current Articles of Association (Satzung) of the Foundation. If there is a conflict between the English and German versions of the Articles, the German version prevails.
1. **Board** means the Board of Directors of the Foundation.
1. **Board Member** means an individual member of the Board.
1. **Bylaws** means this document.
1. **Caretaker** means a member of the Foundation.
1. **Conference** means an audio or video teleconference.
1. **Foundation** means the Interplanetary Database Foundation e.V.
1. **IPDB** means the Interplanetary Database, a decentralized database made up of the cluster of Nodes operated by Caretakers.
1. **Key Pair** means a cryptographic public-private key pair generated by a Board Member, Caretaker, or Representative by the means set out in Policy.
1. **Node** means an instance of the Software operated by a Caretaker.
1. **Policy** means policies, procedures, or other guidelines approved by the Board.
1. **Private Key** means the half of a Key Pair used by Caretakers to sign blocks or votes or by Board Members or Representatives to sign votes.
1. **Public Key** means the half of a Key Pair publicly associated with a Board Member, Caretaker, or Representative and serves as their identifier on IPDB or within the Foundation.
1. **Representative** means an individual or individuals designated by a Caretaker to be the Staff’s point of contact for that Caretaker, with the authority to vote on the Caretaker’s behalf in Caretakers’ meetings.
1. **Software** means the software the Board determines must be run on each Node.
1. **Staff** means individuals appointed by the Board to administer the day-to-day activities of the Foundation.

# Structure

1. The Foundation will be registered in Berlin, Germany, as a charitable organization.
1. The Bylaws expand on the text of the Articles. If there is a conflict between the Bylaws and the Articles, the Articles prevail.

# Board (Article 6)

## Board meetings

1. The Board will meet at least once per quarter.
1. Board Members may attend Board meetings in person or by Conference.
1. Additional Board meetings can be called with the agreement of two Board Members.
1. A Board meeting quorum is met if at least 3 Board Members are in attendance.

## Votes by board members

1. Board Members may cast votes in person, by Conference, or by email.
1. Votes by voice can be cast in person or by Conference.
1. Votes in writing must be cast by email and, if required by Policy, must be signed with the Board Member’s Private Key.

## Board elections

1. The Board will determine the date of elections for the Board.
1. Staff will deliver notice of a Board election, listing any vacancies and candidates nominated by the Board, within one month of the election, by email to the Representatives and on a page on the Foundation website.
1. The Board may nominate candidates for vacancies on the Board to be delivered with notice of the Board election, or at any time up to two weeks before the election.
1. Caretakers may nominate candidates for vacancies on the Board at any time after notice of the Board election has been delivered, or at any time up to two weeks before the election.
1. All candidates may provide a 500 character biography and a URL to be posted on the Foundation website.
1. Staff will deliver a final notice of the Board election, along with a complete list of candidates and their biographies, two weeks before the election.

## Staff

1. The Board may delegate authority to Staff, including signing authority for the Foundation.
1. The scope of authority granted to Staff must be clearly set out by the Board in its grant of authority.
1. The Board will appoint at least one person as Staff to perform the duties set out in the Bylaws.

# Advisors (Article 7)

1. Advisors are appointed by a majority vote by the Board.
1. Consultations between Board Members and Advisors can be kept in confidence as between the Board Member and the Advisor.
1. The Board may establish Advisory Committees to provide advice in their areas of expertise.
1. The Board may delegate the development of Policies to an Advisory Committee established for that purpose.
1. The Board may vote to request formal advice from Advisors or Advisory Committees. 1. The response to such a request will be made public.

# Caretakers (Articles 3-5)

## Caretaker representatives

1. Caretakers must nominate at least one individual as a Representative.
1. The Representative must generate a Key Pair.

## Caretakers’ meetings

1. Staff will provide notice of meetings of the Caretakers to the Caretakers’ Representatives
1. Caretakers may attend meetings in person or by Conference.

## Votes by caretakers

1. Caretakers’ Representatives vote on behalf of the Caretakers.
1. Representatives may cast votes in person, by Conference, or by email.
1. Votes by voice can be cast in person or by Conference.
1. Votes in writing must be cast by email and, if required by Policy, must be signed with the Representative’s Private Key.

## Number of caretakers

1. The Foundation may have no more than 100 Caretakers.
1. The Board may admit a maximum of 20 Caretakers each year, at the discretion of the Board.

## Adding caretakers (Article 3)

1. Entities that wish to become a Caretaker may apply in writing to the Foundation.
1. The Board reviews Applicants with consideration to the requirements and targets listed in this section.
1. To admit an Applicant, the Board must be satisfied that the Applicant is committed to the Foundation’s mission and building a decentralized internet that is open, inclusive, transparent, and diverse.
1. The following requirements for Caretaker diversity must always be met by the current membership:
    1. More than 50% of Caretakers must be not-for-profit or charitable organizations.
    1. Fewer than 50% of Caretakers may be based in any one country.
    1. The following targets for Caretaker diversity are not requirements, but will be weighted highly in the Board’s determination:
    1. More than 66% of the Caretakers should be not-for-profit or charitable organization.
    1. Fewer than 25% of Caretakers should be based in any one country.
    1. Fewer than 50% of Caretakers should be based in any one region.
    1. At least one Caretaker should be based in each region.

## Expulsion of caretakers

1. The process for expulsion is triggered by a complaint regarding the conduct of the Caretaker brought to the Foundation by a Board Member, another Caretaker, or a member of the public.
1. Staff will receive complaints and present them to the Board as they are received.
Complaints will be addressed at the next regularly scheduled Board meeting.
If the matter is urgent, a special Board meeting can be called if requested by 20% of Caretakers or 2 Board Members.
1. The Board may dismiss a complaint without comment if it is unanimously voted by the Board to be frivolous or unfounded. Votes to dismiss a complaint must be in writing, and must be reported to the Caretakers by the Board along with the complaint.
The Board will call for a comments over a period of 4 weeks, during which all Caretakers, including the subject of the complaint, can present arguments and evidence for or against expulsion.
1. After the comment period the Board will consider the factors below, then either dismiss the complaint as unfounded or recommend that the Caretakers vote to expel the subject of the complaint.
1. All Caretakers except the subject of the complaint may vote on the Board’s recommendation. If the vote passes, the subject of the complaint is expelled from the Foundation and their keys will be invalidated immediately.

## Grounds for expulsion

1. The following factors will be considered by the Board and Caretakers in reviewing the subject of a complaint:
    1. Actions by the Caretaker determined to be in violation of the Articles or the mission statement of the Foundation.
    1. Deliberate tampering with the validity or integrity of IPDB.
    1. Failure to comply with Policies for security, privacy, or operating a Node.
    1. Failure of the Representative to respond to communications from Staff in a timely manner.
    1. Actions by the Caretaker determined to be detrimental to the success, functioning, or reputation of IPDB or the Foundation.

# Keys

## Generating keys

1. Caretakers and Representatives will generate Key Pairs in the manner set in Policy.

## Securing keys

1. Caretakers and Representatives will communicate their Public Keys to the Foundation in the manner set in Policy.
1. Private keys will be secured in the manner set in Policy.

## Revoking signing authority

1. If a complaint against a Caretaker is brought to the Board, that Caretaker’s authority to sign blocks on IPDB will be suspended.
1. Signing authority can be reinstated if the complaint is unfounded or dismissed.

# Nodes

## Operating a node

1. Nodes can be operated on hardware operated by third party providers or hardware managed by the Caretaker.
1. Caretakers without the technical capacity to maintain a Node may, with the approval of the Board, retain a part-time system administrator to maintain the Node, or be paired with another Caretaker who can offer assistance.

## Cloud accounts

1. The Foundation will provide Caretakers cloud accounts on which to run the Software.
Caretakers must manage their credentials in accordance with Policy.
1. Cloud accounts can only be used to operate the Software.

## Security

1. Caretakers must follow all security Policy approved by the Board.

## Software

1. Caretakers must run the version of the Software approved by the Board, and must upgrade in accordance with Policy approved by the Board.

# Privacy and Information Handling

1. Caretakers must follow all privacy Policy approved by the Board.
1. Caretakers may release information to third parties only if it is required to comply with a binding legal processes such as a court order or a warrant, except as defined in privacy Policy approved by the Board.
1. If a Caretaker or the Foundation receives any legal request, order, or demand, the recipient must notify Staff and the other Caretakers immediately.
1. Caretakers will put a file in a public location on their website called canary.txt and will remove that file if the Caretaker has received a legal request, order, or demand but is restrained from notifying the Caretakers or the Foundation of the request.
